exclude :test___dir__, "needs investigation"
exclude :test_argument_error_location, "argument errors are calculated differently in JRuby"
exclude :test_body, "fails due RubyVM constant"
exclude :test_callee, "fails for unoptimized define_method due to capturing a frame"
exclude :test_define_method_visibility, "needs investigation"
exclude :test_gced_bmethod, "often 'Timeout::Error: execution of assert_normal_exit expired' on CI"
exclude :test_hash, "won't pass since Array#map is not a Array#collect alias as in MRI"
exclude :test_prepended_public_zsuper, "2.4 fix/change to prepend + method + super_method (#4687)"
exclude :test_splat_long_array, "passes locally but fails on travis OOME"
exclude :test_to_proc_binding, "NullPointerException in parser"
